# Changelog — `latexrestricted` Python package


## v0.3.0 (2024-08-11)

*  Fixed `__slots__` bug in `AnyPath`.

*  Replaced all `$TEXMF*` with `TEXMF*` in error messages and documentation
   for better consistency.


## v0.2.0 (2024-08-10)

*  Added check for unsafe `TEXMFOUTPUT` value in TeX Live config.


## v0.1.0 (2024-07-27)

*  Initial release.
